# FourierOptics
This is a Python library that attempts to streamline simulation of optical setups in the Fourier domain. It provides several methods of simulating wave propagation as well as providing commonly used apertures and helper functions to determine which methods of propagation are valid.


## Examples

```Python
import fourier
```
